@@ -4,7 +4,7 @@
  * Copyright (C) 2003 Laurent Sansonetti <lrz@gnome.org>
  * Copyright (C) 2005 Dan Winship <danw@src.gnome.org>
  * Copyright (C) 2005 - 2012 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2005 lvaro Pea <alvaropg@telefonica.net>
+ * Copyright (C) 2005 Ãlvaro PeÃ±a <alvaropg@telefonica.net>
  * Copyright (C) 2007 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2011 Daniel Espinosa <despinosa@src.gnome.org>
  *
@@ -64,9 +64,18 @@ typedef enum {
 	GDA_DATA_MODEL_HINT_REFRESH
 } GdaDataModelHint;
 
+/**
+ * GdaDataModelIOFormat:
+ * @GDA_DATA_MODEL_IO_DATA_ARRAY_XML: data is exported as an XML structure
+ * @GDA_DATA_MODEL_IO_TEXT_SEPARATED: data is exported as CSV
+ * @GDA_DATA_MODEL_IO_TEXT_TABLE: data is exported as a human readable table
+ *
+ * Format to use when exporting a data model, see gda_data_model_export_to_string() and gda_data_model_export_to_file()
+ */
 typedef enum {
 	GDA_DATA_MODEL_IO_DATA_ARRAY_XML,
-	GDA_DATA_MODEL_IO_TEXT_SEPARATED
+	GDA_DATA_MODEL_IO_TEXT_SEPARATED,
+	GDA_DATA_MODEL_IO_TEXT_TABLE
 } GdaDataModelIOFormat;
 
 typedef enum {
